import { joinUser, taskFile, getViewLogList, codeFile, taskList, getSubscribeList, getTaskFileList } from '@/api/table'
import { getToken } from '@/utils/auth'
import { parseTime } from '@/utils/index'

const user = {
  state: {
    uid: getToken(),
    joinUserList: [],
    fileList: [],
    logList: [],
    logNameList: [],
    codeList: [],
    totalSize: 0,
    logSize: 0,
    subscribeList: [],
    taskFileList: [],
    fileDetailsList: [],
    taskNameList: []
  },

  mutations: {
    SET_JOINUSERLIST: (state, list) => {
      state.joinUserList = list
    },
    SET_FILELIST: (state, data) => {
      state.fileList = [...data.localFile, ...data.screenshot, ...data.mergeFile, ...data.recordFile]
    },
    SET_LOGLIST: (state, data) => {
      // 转换数据格式
      const list = data.list
      const newArr = []
      const logNameList = []
      if (list.length > 0) {
        list.forEach((item, ind) => {
          logNameList.push(
            {
              name: item.task.title,
              created: parseTime(item.task.gmtCreated)
            }
          )
          newArr.push([])
          item.recordFile.length === 0 ? newArr : newArr[ind].push(
            {
              fileName: item.recordFile[0].fileName,
              path: item.recordFile[0].path,
              ind
            }
          )
          item.screenshot.length === 0 ? newArr : newArr[ind].push(
            {
              fileName: item.screenshot[0].fileName,
              path: item.screenshot[0].path,
              ind
            }
          )
          item.localFile.forEach(file => {
            newArr[ind].push(file)
          })
        })
      }
      state.logList = newArr
      state.logNameList = logNameList
      state.logSize = data.totalSize
    },
    SET_TOTALSIZE: (state, size) => {
      state.totalSize = size
    },
    SET_CODELIST: (state, data) => {
      state.codeList = [...data.localFile, ...data.screenshot]
    },
    // 获取订阅用户
    SET_SUBSCRIBELIST: (state, list) => {
      state.subscribeList = list
    },
    // 获取订阅用户文件
    SET_TASKFILELIST: (state, list) => {
      state.fileDetailsList = list
      sessionStorage.setItem('fileDetailsList', JSON.stringify(list))
      // 转换数据格式
      const newArr = []
      const taskNameList = []
      if (list.length > 0) {
        list.forEach((item, ind) => {
          taskNameList.push(
            {
              name: item.task.title,
              created: parseTime(item.task.gmtCreated)
            }
          )
          newArr.push([])
          item.recordFile.length === 0 ? newArr : newArr[ind].push(
            {
              fileName: item.recordFile[0].fileName,
              path: item.recordFile[0].path,
              ind,
              taskId: item.task.id
            }
          )
          item.screenshot.length === 0 ? newArr : newArr[ind].push(
            {
              fileName: item.screenshot[0].fileName,
              path: item.screenshot[0].path,
              ind,
              taskId: item.task.id
            }
          )
          item.localFile.forEach(file => {
            file.taskId = item.task.id
            newArr[ind].push(file)
          })
        })
      }
      state.taskNameList = taskNameList
      state.taskFileList = newArr
    }
  },

  actions: {
    // 获取参会人员
    JoinUser({ commit, state }, pageNo) {
      return new Promise((resolve, reject) => {
        joinUser(getToken(), pageNo, 10).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data.list)
          commit('SET_TOTALSIZE', data.totalSize)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取参会文件
    TaskFile({ commit }, taskId) {
      return new Promise((resolve, reject) => {
        taskFile(taskId).then(response => {
          console.log(response)
          const data = response.data
          commit('SET_FILELIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取浏览信息
    GetViewLogList({ commit }, pageNo) {
      return new Promise((resolve, reject) => {
        getViewLogList(pageNo, 10).then(response => {
          const data = response.data
          commit('SET_LOGLIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 输入授权码获取会议资料
    CodeFile({ commit, state }, code) {
      return new Promise((resolve, reject) => {
        codeFile(code).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data)
          // commit('SET_TOTALSIZE', data.totalSize)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取会议文件
    TaskList({ commit, state }, pageNo) {
      return new Promise((resolve, reject) => {
        taskList(getToken(), pageNo, 10).then(response => {
          const data = response.data
          commit('SET_JOINUSERLIST', data.list)
          commit('SET_TOTALSIZE', data.totalSize)
          resolve(data.list)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取订阅列表
    GetSubscribeList({ commit }) {
      return new Promise((resolve, reject) => {
        getSubscribeList(getToken()).then(response => {
          const data = response.data
          commit('SET_SUBSCRIBELIST', data)
        }).catch(error => {
          reject(error)
        })
      })
    },
    // 获取订阅列表文件
    GetTaskFileList({ commit }, uid) {
      return new Promise((resolve, reject) => {
        getTaskFileList(uid).then(response => {
          const data = response.data
          commit('SET_TASKFILELIST', data)
          resolve(data)
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
